@@ -215,7 +215,6 @@ cleanup_ctx (struct TM_HandlerContext *hc)
 /**
  * Transmit a payment request for @a order_id on @a connection
  *
- * @param connection MHD connection
  * @param order_id our backend's order ID
  * @param token the claim token generated by the merchant (NULL if
  *        it wasn't generated).
@@ -381,7 +380,7 @@ ongoing_payment_cb (void *cls,
   (void) amount;
   if (0 != TALER_amount_cmp (amount,
                              &SH_annual_fee))
-    return; /* can't re-use, fees changed */
+    return; /* can't reuse, fees changed */
   if ( (NULL == bc->existing_order_id) ||
        (GNUNET_TIME_timestamp_cmp (bc->existing_order_timestamp,
                                    <,
@@ -682,16 +681,6 @@ handle_database_error (struct BackupContext *bc,
 }
 
 
-/**
- * Handle a client POSTing a backup to us.
- *
- * @param connection the MHD connection to handle
- * @param[in,out] connection_cls the connection's closure (can be updated)
- * @param account public key of the account the request is for
- * @param upload_data upload data
- * @param[in,out] upload_data_size number of bytes (left) in @a upload_data
- * @return MHD result code
- */
 MHD_RESULT
 SH_backup_post (struct MHD_Connection *connection,
                 void **con_cls,
